<img width="300px" src="https://sickrage.ca/img/logo-stacked.png" />

# 

##Fri Aug 07 2020 16:55:45 GMT+0000 (Coordinated Universal Time)


## Refactor
  - Refactored database backup/restore code Bumped main database to v16 Fixed issue with returning scene absolute number by lookup of indexer absolute number when absolute number is zero and returns multiple rows Removed psutil from requirements.txt Refactored file cleanup on start to skip *.pyc files Remover memory_usage function from helpers
  ([96cdca42](https://gitlab-ci-token:msyqhYZwXjoMN7JJVyXp@git.sickrage.ca/SiCKRAGE/sickrage/commit/96cdca42ae73a78ad4274918cd935b93e1995e36))




